==> nocc-1.9.5.txz: usr/local/www/nocc/lang/es.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: es.php 2623 2014-10-06 10:07:46Z siebrand $
 */
/** Spanish (español)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Crazymadlover
 * @author Dalton2
 * @author Dferg
 * @author Fitoschido
 * @author Gustavo Muslera <gmuslera@internet.com.uy>
 * @author Locos epraix
 * @author Macofe
 * @author MarcoAurelio
 * @author Od1n
 * @author Peter17
 * @author Translationista
 * @author VegaDark
 * @author Vivaelcelta
 */

$lang_locale = 'es_ES.UTF-8';
$default_date_format = '%Y-%m-%d';
$no_locale_date_format = '%Y-%m-%d';
$default_time_format = '%I:%M %p';
$err_user_empty = 'El campo de usuario está vacío';
$err_passwd_empty = 'El campo de contraseña está vacío';
$alt_delete = 'Eliminar mensajes seleccionados';
$alt_delete_one = 'Eliminar mensaje';
$alt_new_msg = 'Nuevos mensajes';
$alt_reply = 'Responder al autor';
$alt_reply_all = 'Responder a todos';
$alt_forward = 'Reenviar';
$alt_next = 'Siguiente';
$alt_prev = 'Anterior';
$title_next_page = 'Página siguiente';
$title_prev_page = 'Página anterior';
$title_next_msg = 'Mensaje siguiente';
$title_prev_msg = 'Mensaje anterior';
$html_theme_label = 'Tema:';
$html_welcome = 'Bienvenido a %1$s';
$html_login = 'Inicio de sesión';
$html_user_label = 'Usuario:';
$html_passwd_label = 'Contraseña:';
$html_submit = 'Aceptar';
$html_help = 'Ayuda';
$html_server_label = 'Servidor:';
$html_wrong = 'El usuario o la contraseña son incorrectos';
$html_retry = 'Reintentar';
$html_remember = 'Recordar opciones';
$html_lang_label = 'Idioma:';
$html_msgperpage_label = 'Mensajes por página:';
$html_preferences = 'Preferencias';
$html_full_name_label = 'Nombre completo:';
$html_email_address_label = 'Dirección de correo electrónico:';
$html_bccself = 'Enviarme una copia oculta';
$html_hide_addresses = 'Ocultar direcciones';
$html_outlook_quoting = 'Citas tipo Outlook';
$html_reply_to = 'Responder a';
$html_reply_to_label = 'Responder a:';
$html_use_signature = 'Usar firma';
$html_signature = 'Firma';
$html_signature_label = 'Firma:';
$html_reply_leadin_label = 'Prefijo de respuesta:';
$html_prefs_updated = 'Preferencias actualizadas';
$html_manage_folders_link = 'Gestionar carpetas IMAP';
$html_manage_filters_link = 'Gestionar filtros de mensajes';
$html_use_graphical_smilies = 'Usar \'smilies\' gráficos';
$html_sent_folder_label = 'Copiar correos electrónicos enviados a una carpeta específica:';
$html_trash_folder_label = 'Trasladar correos electrónicos eliminados a una carpeta específica:';
$html_colored_quotes = 'Citas con colores';
$html_display_struct = 'Mostrar texto estructurado';
$html_send_html_mail = 'Enviar mensajes en formato HTML';
$html_folders = 'Carpetas';
$html_folders_create_failed = 'No se pudo crear la carpeta';
$html_folders_sub_failed = 'No se pudo suscribir a la carpeta';
$html_folders_unsub_failed = 'No se pudo desuscribir de la carpeta';
$html_folders_rename_failed = 'No se pudo cambiar el nombre a la carpeta';
$html_folders_updated = 'Carpetas actualizadas';
$html_folder_subscribe = 'Suscribir a';
$html_folder_rename = 'Renombrar';
$html_folder_create = 'Crear nueva carpeta llamada';
$html_folder_remove = 'Desuscribir de';
$html_folder_delete = 'Borrar';
$html_folder_to = 'a';
$html_filter_remove = 'Borrar';
$html_filter_body = 'Cuerpo del mensaje';
$html_filter_subject = 'Asunto del mensaje';
$html_filter_to = 'Campo Para';
$html_filter_cc = 'Campo CC';
$html_filter_from = 'Campo De';
$html_filter_change_tip = 'Para cambiar un filtro, simplemente sobreescríbalo.';
$html_reapply_filters = 'Re-aplicar todos los filtros';
$html_filter_contains = 'contiene';
$html_filter_name = 'Nombre del filtro';
$html_filter_action = 'Acción del filtro';
$html_filter_moveto = 'Trasladar a';
$html_select_one = '-- Seleccione uno --';
$html_and = 'Y';
$html_new_msg_in = 'Nuevos mensajes en';
$html_or = 'O';
$html_move = 'Trasladar';
$html_copy = 'Copiar';
$html_messages_to = 'los mensajes seleccionados a';
$html_gotopage = 'Ir a la página';
$html_gotofolder = 'Ir a la carpeta';
$html_other_folders = 'Lista de carpetas';
$html_page = 'Página';
$html_of = 'de';
$html_view_header = 'Ver encabezado';
$html_remove_header = 'Ocultar encabezado';
$html_inbox = 'Bandeja de entrada';
$html_new_msg = 'Escribir';
$html_reply = 'Responder';
$html_reply_short = 'Re:';
$html_reply_all = 'Responder a todos';
$html_forward = 'Reenviar';
$html_forward_short = 'Fwd:';
$html_forward_info = 'Los mensajes reenviados se enviarán como archivos adjuntos al nuevo mensaje.';
$html_delete = 'Borrar';
$html_new = 'Nuevo';
$html_mark = 'Borrar';
$html_att_label = 'Adjunto:';
$html_atts_label = 'Adjuntos:';
$html_unknown = '[desconocido]';
$html_part_x = 'Parte %s';
$html_attach = 'Adjuntar';
$html_attach_forget = '¡Debe adjuntar sus archivos antes de enviar su mensaje!';
$html_attach_delete = 'Eliminar los seleccionados';
$html_attach_none = '¡Debe seleccionar un archivo a adjuntar!';
$html_sort_by = 'Ordenar por';
$html_sort = 'Ordenar';
$html_from = 'De';
$html_from_label = 'De:';
$html_subject = 'Asunto';
$html_subject_label = 'Asunto:';
$html_date = 'Fecha';
$html_date_label = 'Fecha:';
$html_sent_label = 'Enviado:';
$html_wrote = 'escribió';
$html_quote_wrote = 'El %1$s a las %2$s, %3$s escribió:';
$html_size = 'Tamaño';
$html_totalsize = 'Tamaño total';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'bytes';
$html_filename = 'Archivo';
$html_to = 'A';
$html_to_label = 'A:';
$html_cc = 'Cc';
$html_cc_label = 'Cc:';
$html_bcc_label = 'Bcc:';
$html_nosubject = 'Sin asunto';
$html_send = 'Enviar';
$html_cancel = 'Cancelar';
$html_no_mail = 'No hay mensajes nuevos.';
$html_logout = 'Salir';
$html_msg = 'Mensaje';
$html_msgs = 'Mensajes';
$html_configuration = '¡Este servidor no está bien configurado!';
$html_priority = 'Prioridad';
$html_priority_label = 'Prioridad:';
$html_lowest = 'La más baja';
$html_low = 'Baja';
$html_normal = 'Normal';
$html_high = 'Alta';
$html_highest = 'La más alta';
$html_flagged = 'Marcado';
$html_spam = 'Spam';
$html_spam_warning = 'Este mensaje ha sido clasificado como spam.';
$html_receipt = 'Solicitar una confirmación de entrega';
$html_select = 'Seleccionar';
$html_select_all = 'Invertir selección';
$html_select_contacts = 'Seleccionar contactos';
$html_loading_image = 'Cargando imagen';
$html_send_confirmed = 'Su correo ha sido enviado correctamente';
$html_no_sendaction = 'No se ha especificado una acción. Intente probar de nuevo habilitando JavaScript.';
$html_error_occurred = 'Ha ocurrido un error';
$html_prefs_file_error = 'Imposible abrir el archivo de preferencias para cambiarlo.';
$html_wrap = 'Número de caracteres para envolver mensajes de salida:';
$html_wrap_none = 'Sin envoltura';
$html_usenet_separator = 'Separador en noticias de Usenet ("-- \n") antes de la firma';
$html_mark_as = 'Marcar como';
$html_read = 'leído';
$html_unread = 'no leído';
$html_encoding_label = 'Codificación de caracteres:';
$html_add = 'Añadir';
$html_contacts = '%1$s Contactos';
$html_modify = 'Modificar';
$html_back = 'Volver';
$html_contact_add = 'Añadir nuevo contacto';
$html_contact_mod = 'Modificar contacto';
$html_contact_first = 'Nombre';
$html_contact_last = 'Apellido';
$html_contact_nick = 'Apodo';
$html_contact_mail = 'Correo electrónico';
$html_contact_list = 'Lista de contactos de %1$s';
$html_contact_del = 'de la lista decontactos';
$html_contact_count = '%1$d Contactos';
$html_contact_err1 = 'El número máximo de contactos es "%1$d"';
$html_contact_err2 = 'No puede añadir un nuevo contacto';
$html_contact_err3 = 'No tiene permisos de acceso a la lista de contactos';
$html_contact_none = 'No se encontró ningún contacto.';
$html_del_msg = '¿Eliminar mensajes seleccionados?';
$html_down_mail = 'Descargar';
$original_msg = '-- Mensaje Original --';
$to_empty = '¡El campo \'Para\' no debe estar vacio!';
$html_images_warning = 'Para su seguridad, las imágenes remotas no serán mostradas.';
$html_images_display = 'Mostrar imágenes';
$html_smtp_error_no_conn = 'Imposible abrir conexión SMTP';
$html_smtp_error_unexpected = 'Respuesta inesperada de SMTP:';
$lang_could_not_connect = 'No se pudo conectar al servidor';
$lang_invalid_msg_num = 'Número incorrecto de mensajes';
$html_file_upload_attack = 'Posible ataque el enviar archivo';
$html_invalid_email_address = 'Dirección de correo electrónico no válida';
$html_invalid_msg_per_page = 'Número de mensajes por página no válido';
$html_invalid_wrap_msg = 'Ancho de ajuste de mensaje no válido';
$html_seperate_msg_win = 'Mensajes en una ventana separada';
$html_err_file_contacts = 'No se pudo abrir el archivo de contactos para escritura.';
$html_session_file_error = 'No se pudo abrir el archivo de sesiones para escritura.';
$html_login_not_allowed = 'Este nombre de inicio de sesión no está permitido para conexión.';
$lang_err_send_delay = 'Debes esperar entre dos correos (%1$d segundos)';
$html_search = 'Buscar';
$html_new_session = 'Próxima sesión';
$html_fd_filename = 'Descargar %1$s';
$html_fd_mailcount = '{{PLURAL:$1|0=No hay mensajes|1=Hay %1$d mensaje|Hay %1$d mensajes}} en la carpeta.';
$html_fd_mailskip = 'Los mensajes siguientes no formarán parte del archivo mbox porque excederían el valor «memory_limit» de PHP:';
$html_fd_filesize = 'tamaño %1$d';
$html_fd_skipcount = 'con %1$d mensajes';
$html_fd_largefolder = 'Dependiendo de tu velocidad de descarga, esta descarga puede fallar debido al tiempo de espera del script.<br />Por favor revisa la descarga por completa o establece max_execution_time a un valor más alto en php.ini.';
$reset_clicked = '¿Estás seguro de querer borrar este formulario?';
$html_send_recover = '¡Inicia sesión para recuperar el borrador perdidoǃ';
$html_send_discard = 'Haz clic aquí para descartar el borrador guardado.';

==> nocc-1.9.6.txz: usr/local/www/nocc/lang/es.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: es.php 2664 2016-05-23 07:58:44Z siebrand $
 */
/** Spanish (español)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Crazymadlover
 * @author Dalton2
 * @author Dferg
 * @author Fitoschido
 * @author Gustavo Muslera <gmuslera@internet.com.uy>
 * @author Indiralena
 * @author Locos epraix
 * @author Macofe
 * @author MarcoAurelio
 * @author Od1n
 * @author Peter17
 * @author Translationista
 * @author VegaDark
 * @author Vivaelcelta
 */

$lang_locale = 'es_ES.UTF-8';
$default_date_format = '%Y-%m-%d';
$no_locale_date_format = '%Y-%m-%d';
$default_time_format = '%I:%M %p';
$err_user_empty = 'El campo de usuario está vacío';
$err_passwd_empty = 'El campo de contraseña está vacío';
$alt_delete = 'Eliminar mensajes seleccionados';
$alt_delete_one = 'Eliminar mensaje';
$alt_new_msg = 'Nuevos mensajes';
$alt_reply = 'Responder al autor';
$alt_reply_all = 'Responder a todos';
$alt_forward = 'Reenviar';
$alt_next = 'Siguiente';
$alt_prev = 'Anterior';
$title_next_page = 'Página siguiente';
$title_prev_page = 'Página anterior';
$title_next_msg = 'Mensaje siguiente';
$title_prev_msg = 'Mensaje anterior';
$html_theme_label = 'Tema:';
$html_welcome = 'Bienvenido a %1$s';
$html_login = 'Iniciar sesión';
$html_user_label = 'Usuario:';
$html_passwd_label = 'Contraseña:';
$html_submit = 'Enviar';
$html_help = 'Ayuda';
$html_server_label = 'Servidor:';
$html_wrong = 'El usuario o la contraseña son incorrectos';
$html_retry = 'Reintentar';
$html_remember = 'Recordarme';
$html_lang_label = 'Idioma:';
$html_msgperpage_label = 'Mensajes por página:';
$html_preferences = 'Preferencias';
$html_full_name_label = 'Nombre completo:';
$html_email_address_label = 'Dirección de correo electrónico:';
$html_bccself = 'Enviarme una copia oculta';
$html_hide_addresses = 'Ocultar direcciones';
$html_outlook_quoting = 'Citas tipo Outlook';
$html_reply_to = 'Responder a';
$html_reply_to_label = 'Responder a:';
$html_use_signature = 'Usar firma';
$html_signature = 'Firma';
$html_signature_label = 'Firma:';
$html_reply_leadin_label = 'Prefijo de respuesta:';
$html_prefs_updated = 'Preferencias actualizadas';
$html_manage_folders_link = 'Gestionar carpetas IMAP';
$html_manage_filters_link = 'Gestionar filtros de mensajes';
$html_use_graphical_smilies = 'Usar \'smilies\' gráficos';
$html_sent_folder_label = 'Copiar correos electrónicos enviados a una carpeta específica:';
$html_trash_folder_label = 'Trasladar correos electrónicos eliminados a una carpeta específica:';
$html_colored_quotes = 'Citas con colores';
$html_display_struct = 'Mostrar texto estructurado';
$html_send_html_mail = 'Enviar mensajes en formato HTML';
$html_folders = 'Carpetas';
$html_folders_create_failed = 'No se pudo crear la carpeta';
$html_folders_sub_failed = 'No se pudo suscribir a la carpeta';
$html_folders_unsub_failed = 'No se pudo desuscribir de la carpeta';
$html_folders_rename_failed = 'No se pudo cambiar el nombre a la carpeta';
$html_folders_updated = 'Carpetas actualizadas';
$html_folder_subscribe = 'Suscribir a';
$html_folder_rename = 'Renombrar';
$html_folder_create = 'Crear nueva carpeta llamada';
$html_folder_remove = 'Desuscribir de';
$html_folder_delete = 'Borrar';
$html_folder_to = 'a';
$html_filter_remove = 'Borrar';
$html_filter_body = 'Cuerpo del mensaje';
$html_filter_subject = 'Asunto del mensaje';
$html_filter_to = 'Campo Para';
$html_filter_cc = 'Campo CC';
$html_filter_from = 'Campo De';
$html_filter_change_tip = 'Para cambiar un filtro, simplemente sobreescríbelo.';
$html_reapply_filters = 'Re-aplicar todos los filtros';
$html_filter_contains = 'contiene';
$html_filter_name = 'Nombre del filtro';
$html_filter_action = 'Acción del filtro';
$html_filter_moveto = 'Trasladar a';
$html_select_one = '-- Seleccione uno --';
$html_and = 'Y';
$html_new_msg_in = 'Nuevos mensajes en';
$html_or = 'O';
$html_move = 'Trasladar';
$html_copy = 'Copiar';
$html_messages_to = 'los mensajes seleccionados a';
$html_gotopage = 'Ir a la página';
$html_gotofolder = 'Ir a la carpeta';
$html_other_folders = 'Lista de carpetas';
$html_page = 'Página';
$html_of = 'de';
$html_view_header = 'Ver encabezado';
$html_remove_header = 'Ocultar encabezado';
$html_inbox = 'Bandeja de entrada';
$html_new_msg = 'Escribir';
$html_reply = 'Responder';
$html_reply_short = 'Re:';
$html_reply_all = 'Responder a todos';
$html_forward = 'Reenviar';
$html_forward_short = 'Fwd:';
$html_forward_info = 'Los mensajes reenviados se enviarán como archivos adjuntos al nuevo mensaje.';
$html_delete = 'Borrar';
$html_new = 'Nuevo';
$html_mark = 'Borrar';
$html_att_label = 'Adjunto:';
$html_atts_label = 'Adjuntos:';
$html_unknown = '[desconocido]';
$html_part_x = 'Parte %s';
$html_attach = 'Adjuntar';
$html_attach_forget = '¡Debes adjuntar tus archivos antes de enviar tu mensaje!';
$html_attach_delete = 'Eliminar los seleccionados';
$html_attach_none = '¡Debes seleccionar un archivo que adjuntar!';
$html_sort_by = 'Ordenar por';
$html_sort = 'Ordenar';
$html_from = 'De';
$html_from_label = 'De:';
$html_subject = 'Asunto';
$html_subject_label = 'Asunto:';
$html_date = 'Fecha';
$html_date_label = 'Fecha:';
$html_sent_label = 'Enviado:';
$html_wrote = 'escribió';
$html_quote_wrote = 'El %1$s a las %2$s, %3$s escribió:';
$html_size = 'Tamaño';
$html_totalsize = 'Tamaño total';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'bytes';
$html_filename = 'Nombre de archivo';
$html_to = 'A';
$html_to_label = 'A:';
$html_cc = 'Cc';
$html_cc_label = 'Cc:';
$html_bcc_label = 'Bcc:';
$html_nosubject = 'Sin asunto';
$html_send = 'Enviar';
$html_cancel = 'Cancelar';
$html_no_mail = 'No hay mensajes nuevos.';
$html_logout = 'Salir';
$html_msg = 'Mensaje';
$html_msgs = 'Mensajes';
$html_configuration = '¡Este servidor no está bien configurado!';
$html_priority = 'Prioridad';
$html_priority_label = 'Prioridad:';
$html_lowest = 'La más baja';
$html_low = 'Baja';
$html_normal = 'Normal';
$html_high = 'Alta';
$html_highest = 'La más alta';
$html_flagged = 'Marcado';
$html_spam = 'Spam';
$html_spam_warning = 'Este mensaje ha sido clasificado como spam.';
$html_receipt = 'Solicitar una confirmación de entrega';
$html_select = 'Seleccionar';
$html_select_all = 'Invertir selección';
$html_select_contacts = 'Seleccionar contactos';
$html_loading_image = 'Cargando imagen';
$html_send_confirmed = 'Tu correo ha sido aceptado para su entrega';
$html_no_sendaction = 'No se ha especificado una acción. Intenta habilitar JavaScript.';
$html_error_occurred = 'Ha ocurrido un error';
$html_prefs_file_error = 'Imposible abrir el archivo de preferencias para cambiarlo.';
$html_wrap = 'Número de caracteres al que ajustar los mensajes salientes:';
$html_wrap_none = 'Sin envoltura';
$html_usenet_separator = 'Separador en noticias de Usenet ("-- \n") antes de la firma';
$html_mark_as = 'Marcar como';
$html_read = 'leído';
$html_unread = 'no leído';
$html_encoding_label = 'Codificación de caracteres:';
$html_add = 'Añadir';
$html_contacts = '%1$s Contactos';
$html_modify = 'Modificar';
$html_back = 'Volver';
$html_contact_add = 'Añadir nuevo contacto';
$html_contact_mod = 'Modificar contacto';
$html_contact_first = 'Nombre';
$html_contact_last = 'Apellido';
$html_contact_nick = 'Apodo';
$html_contact_mail = 'Correo electrónico';
$html_contact_list = 'Lista de contactos de %1$s';
$html_contact_del = 'de la lista decontactos';
$html_contact_count = '%1$d Contactos';
$html_contact_err1 = 'El número máximo de contactos es "%1$d"';
$html_contact_err2 = 'No puedes añadir un contacto nuevo';
$html_contact_err3 = 'No tienes permisos de acceso a la lista de contactos';
$html_contact_none = 'No se encontró ningún contacto.';
$html_contact_ruler_top = 'Arriba';
$html_contact_listcheck_title = 'Marca para añadir el correo electrónico a la lista.';
$html_contact_list_add = 'Añadir a la lista';
$html_contact_listname = 'Nombre de la lista';
$html_contact_listonly = 'Solo listas';
$html_contact_all = 'Mostrar todo';
$html_contact_add_confirm = '¿Anexar correos electrónicos a la lista existente?';
$html_del_msg = '¿Eliminar mensajes seleccionados?';
$html_down_mail = 'Descargar';
$original_msg = '-- Mensaje Original --';
$to_empty = '¡El campo \'Para\' no debe estar vacio!';
$html_images_warning = 'Para tu seguridad, las imágenes remotas no se muestran.';
$html_images_display = 'Mostrar imágenes';
$html_smtp_error_no_conn = 'Imposible abrir conexión SMTP';
$html_smtp_error_unexpected = 'Respuesta inesperada de SMTP:';
$lang_could_not_connect = 'No se pudo conectar al servidor';
$lang_invalid_msg_num = 'Número incorrecto de mensajes';
$html_file_upload_attack = 'Posible ataque el enviar archivo';
$html_invalid_email_address = 'Dirección de correo electrónico no válida';
$html_invalid_msg_per_page = 'Número de mensajes por página no válido';
$html_invalid_wrap_msg = 'Ancho de ajuste de mensaje no válido';
$html_seperate_msg_win = 'Mensajes en una ventana separada';
$html_err_file_contacts = 'No se pudo abrir el archivo de contactos para escritura.';
$html_session_file_error = 'No se pudo abrir el archivo de sesiones para escritura.';
$html_login_not_allowed = 'Este nombre de inicio de sesión no está permitido para conexión.';
$lang_err_send_delay = 'Debes esperar entre dos correos (%1$d segundos)';
$html_search = 'Buscar';
$html_new_session = 'Próxima sesión';
$html_fd_filename = 'Descargar %1$s';
$html_fd_mailcount = '{{PLURAL:$1|0=No hay mensajes|1=Hay %1$d mensaje|Hay %1$d mensajes}} en la carpeta.';
$html_fd_mailskip = 'Los mensajes siguientes no formarán parte del archivo mbox porque excederían el valor «memory_limit» de PHP:';
$html_fd_filesize = 'tamaño %1$d';
$html_fd_skipcount = 'con %1$d mensajes';
$html_fd_largefolder = 'Dependiendo de tu velocidad de descarga, esta descarga puede fallar debido al tiempo de espera del script.<br />Revisa que la descarga esté completa o establece max_execution_time a un valor más alto en php.ini.';
$reset_clicked = '¿Estás seguro de querer borrar este formulario?';
$html_send_recover = '¡Inicia sesión para recuperar el borrador perdidoǃ';
$html_send_discard = 'Haz clic aquí para descartar el borrador guardado.';
$html_collect_label = 'Auto recolectar direcciones de correo electrónico:';
$html_collect_option0 = 'Nunca';
$html_collect_option1 = 'Solo de correos electrónicos salientes';
$html_collect_option2 = 'Solo a partir de correos electrónicos abiertos';
$html_collect_option3 = 'Siempre';
